@@ -13,7 +13,7 @@ class DirectedGraphCore(object):
     concept, not the extra functionalities, like calculating sccs, etc.. """
 
     def __init__(self, vertices: Mapping[Any, List[Any]] = None,
-                 vertex_sorting=VertexSortOrder.RANDOM):
+                 vertex_sorting=VertexSortOrder.NATURAL):
         """ Initialises a directed graph (with the provided vertices)
 
         Args:
